@@ -67,7 +67,7 @@ class BaseElement(list):
             elif element is not None:
                 yield conditional_escape(element) if stringify else element
         except (Exception, RuntimeError) as e:
-            _handle_exception(e, context)
+            yield from _handle_exception(e, context)
 
     def render_children(
         self, context: dict, stringify: bool = True
@@ -349,7 +349,11 @@ class FormatString(BaseElement):
         self.kwargs = kwargs
 
     def render(self, context):
-        return ContextFormatter(context).format(*self.args, **self.kwargs)
+        yield from self._try_render(
+            ContextFormatter(context).format(*self.args, **self.kwargs),
+            context,
+            stringify=True,
+        )
 
 
 def format(*args, **kwargs):
